"""
    domonic.constants
    ====================================

"""

namespaces = {'xml': 'http://www.w3.org/XML/1998/namespace', 'svg': 'http://www.w3.org/2000/svg', 'xlink': 'http://www.w3.org/1999/xlink',
              'xmlns': 'http://www.w3.org/2000/xmlns/', 'xm': 'http://www.w3.org/2001/xml-events', 'xh': 'http://www.w3.org/1999/xhtml'}


# gravitational_constant = 6.67384e-11
# planck_constant = 6.62606957e-34
# speed_of_light = 299792458
# electron_charge = 1.602176565e-19
# electron_mass = 9.10938291e-31
# proton_mass = 1.672621777e-27
# neutron_mass = 1.674927351e-27
# atomic_mass_unit = 1.660539040e-24
# avogadro_constant = 6.02214129e23
# boltzmann_constant = 1.3806488e-23
# gas_constant = 8.3144621

# i love #copilot
